Function inspect_elects

pub fn inspect_elects<T: Config>()
Emit the currently revealed elected author set as an event for inspection.

This is a read-only convenience extrinsic that does not mutate any state. It retrieves the election result from the underlying election manager via Pallet::get_elects and emits it as an [Event::InspectElects] event.

Notes

  • Gated by the dev feature. Must not be included in production runtimes.
  • Fails if no election result is available, i.e. no election has been executed or the result cannot be revealed.

Errors

Returns Error::UnableToRevealElected if the election result is unavailable.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in [Pallet::inspect_elects].